@@ -12,6 +12,7 @@
 
 #include <gio/gio.h>
 #include <gio/gunixfdlist.h>
+#include "glib-backports.h"
 #include "document-portal-dbus.h"
 #include "document-store.h"
 #include "src/xdp-utils.h"
@@ -1497,8 +1498,8 @@ on_name_lost (GDBusConnection *connection,
   g_main_loop_quit (loop);
 }
 
-int
-on_fuse_unmount (void)
+gboolean
+on_fuse_unmount (void *unused)
 {
   if (!g_main_loop_is_running (loop))
     return G_SOURCE_REMOVE;
@@ -1607,6 +1608,8 @@ main (int    argc,
   g_autoptr(GOptionContext) context = NULL;
   GDBusMethodInvocation *invocation;
 
+  g_log_writer_default_set_use_stderr (TRUE);
+
   setlocale (LC_ALL, "");
 
   /* Avoid even loading gvfs to avoid accidental confusion */
