@@ -44,21 +44,22 @@ typedef struct _TrashClass TrashClass;
 
 struct _Trash
 {
-  XdpTrashSkeleton parent_instance;
+  XdpDbusTrashSkeleton parent_instance;
 };
 
 struct _TrashClass
 {
-  XdpTrashSkeletonClass parent_class;
+  XdpDbusTrashSkeletonClass parent_class;
 };
 
 static Trash *trash;
 
 GType trash_get_type (void) G_GNUC_CONST;
-static void trash_iface_init (XdpTrashIface *iface);
+static void trash_iface_init (XdpDbusTrashIface *iface);
 
-G_DEFINE_TYPE_WITH_CODE (Trash, trash, XDP_TYPE_TRASH_SKELETON,
-                         G_IMPLEMENT_INTERFACE (XDP_TYPE_TRASH, trash_iface_init));
+G_DEFINE_TYPE_WITH_CODE (Trash, trash, XDP_DBUS_TYPE_TRASH_SKELETON,
+                         G_IMPLEMENT_INTERFACE (XDP_DBUS_TYPE_TRASH,
+                                                trash_iface_init));
 
 static guint
 trash_file (XdpAppInfo *app_info,
@@ -68,21 +69,34 @@ trash_file (XdpAppInfo *app_info,
   g_autofree char *path = NULL;
   gboolean writable;
   g_autoptr(GFile) file = NULL;
+  g_autoptr(GError) local_error = NULL;
 
-  path = xdp_app_info_get_path_for_fd (app_info, fd, 0, NULL, &writable);
+  path = xdp_app_info_get_path_for_fd (app_info, fd, 0, NULL, &writable, &local_error);
 
-  if (path == NULL || !writable)
-    return 0;
+  if (path == NULL)
+    {
+      g_debug ("Cannot trash file with invalid fd: %s", local_error->message);
+      return 0;
+    }
+
+  if (!writable)
+    {
+      g_debug ("Cannot trash file \"%s\": not opened for writing", path);
+      return 0;
+    }
 
   file = g_file_new_for_path (path);
-  if (!g_file_trash (file, NULL, NULL))
-    return 0;
+  if (!g_file_trash (file, NULL, &local_error))
+    {
+      g_debug ("Cannot trash file \"%s\": %s", path, local_error->message);
+      return 0;
+    }
 
   return 1;
 }
 
 static gboolean
-handle_trash_file (XdpTrash *object,
+handle_trash_file (XdpDbusTrash *object,
                    GDBusMethodInvocation *invocation,
                    GUnixFDList *fd_list,
                    GVariant *arg_fd)
@@ -100,21 +114,21 @@ handle_trash_file (XdpTrash *object,
 
   result = trash_file (request->app_info, request->sender, fd);
 
-  xdp_trash_complete_trash_file (object, invocation, NULL, result);
+  xdp_dbus_trash_complete_trash_file (object, invocation, NULL, result);
 
-  return TRUE;
+  return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
 
 static void
-trash_iface_init (XdpTrashIface *iface)
+trash_iface_init (XdpDbusTrashIface *iface)
 {
   iface->handle_trash_file = handle_trash_file;
 }
 
 static void
-trash_init (Trash *fc)
+trash_init (Trash *trash)
 {
-  xdp_trash_set_version (XDP_TRASH (fc), 1);
+  xdp_dbus_trash_set_version (XDP_DBUS_TRASH (trash), 1);
 }
 
 static void
