@@ -1751,7 +1751,7 @@ lookup_ns_from_pid_fd (int    pid_fd,
   struct stat st;
   int r;
 
-  g_return_val_if_fail (ns != NULL, FALSE);
+  g_return_val_if_fail (ns != NULL, -1);
 
   r = fstatat (pid_fd, "ns/pid", &st, 0);
   if (r == -1)
@@ -2078,8 +2078,6 @@ xdp_app_info_get_child_pid (JsonNode *root,
   return pid;
 }
 
-#define xdp_lockguard G_GNUC_UNUSED __attribute__((cleanup(xdp_auto_unlock_helper)))
-
 static gboolean
 xdp_app_info_ensure_pidns (XdpAppInfo  *app_info,
                            DIR         *proc,
