@@ -12,8 +12,9 @@
 #include <gio/gio.h>
 #include <gio/gunixfdlist.h>
 
-#include "src/xdp-utils.h"
+#include "xdp-utils.h"
 #include "document-portal/permission-store-dbus.h"
+#include "utils.h"
 
 char outdir[] = "/tmp/xdp-test-XXXXXX";
 
@@ -444,6 +445,113 @@ test_delete4 (void)
   g_assert_true (g_variant_equal (expected, out_perms));
 }
 
+static void
+test_delete5 (void)
+{
+  const char * perms[] = { "yes", NULL };
+  g_autoptr(GVariant) out_perms = NULL;
+  g_autoptr(GVariant) out_data = NULL;
+  g_autoptr(GVariant) expected = NULL;
+  gboolean res;
+  g_autoptr(GError) error = NULL;
+
+  got_result = 0;
+  xdg_permission_store_call_set_permission (permissions, "notifications", TRUE, "notification", "a", perms, NULL, set_cb, NULL);
+  xdg_permission_store_call_delete_permission (permissions, "notifications", "notification", "a", NULL, delete_permission_cb, NULL);
+
+  while (got_result < 2)
+    g_main_context_iteration (NULL, TRUE);
+
+  /* it did not crash during delete permission */
+  g_assert_cmpint (got_result, ==, 2);
+
+  res = xdg_permission_store_call_lookup_sync (permissions,
+                                               "notifications",
+                                               "notification",
+                                               &out_perms,
+                                               &out_data,
+                                               NULL,
+                                               &error);
+
+
+  expected = g_variant_new_array (G_VARIANT_TYPE ("{sas}"), NULL, 0);
+
+  g_assert_true (res);
+  g_assert_no_error (error);
+
+  /* an empty entry is left instead */
+  g_assert_true (g_variant_equal (expected, out_perms));
+}
+
+static void
+test_get_permission1 (void)
+{
+  gboolean res;
+  g_autoptr(GError) error = NULL;
+  g_autofree char **out_perms = NULL;
+
+  res = xdg_permission_store_call_get_permission_sync (permissions,
+                                                       "no-such-table",
+                                                       "no-such-entry",
+                                                       "no-such-app",
+                                                       &out_perms,
+                                                       NULL,
+                                                       &error);
+  g_assert_error (error, XDG_DESKTOP_PORTAL_ERROR, XDG_DESKTOP_PORTAL_ERROR_NOT_FOUND);
+  g_assert_false (res);
+}
+
+static void
+test_get_permission2 (void)
+{
+  gboolean res;
+  const char * in_perms[] = { "yes", NULL };
+  g_autofree char **out_perms = NULL;
+  g_autoptr(GError) error = NULL;
+
+  res = xdg_permission_store_call_set_permission_sync (permissions,
+                                                       "notifications",
+                                                       TRUE,
+                                                       "notification",
+                                                       "a",
+                                                       in_perms,
+                                                       NULL,
+                                                       &error);
+  g_assert_no_error (error);
+  g_assert_true (res);
+
+  res = xdg_permission_store_call_get_permission_sync (permissions,
+                                                       "notifications",
+                                                       "notification",
+                                                       "a",
+                                                       &out_perms,
+                                                       NULL,
+                                                       &error);
+  g_assert_true (res);
+  g_assert_no_error (error);
+  g_assert (g_strv_length (out_perms) == 1);
+  g_assert (g_strv_contains ((const char *const *)out_perms, "yes"));
+}
+
+static void
+test_get_permission3 (void)
+{
+  gboolean res;
+  g_autofree char **out_perms = NULL;
+  g_autoptr(GError) error = NULL;
+
+  res = xdg_permission_store_call_get_permission_sync (permissions,
+                                                       "notifications",
+                                                       "notification",
+                                                       "no-such-app",
+                                                       &out_perms,
+                                                       NULL,
+                                                       &error);
+  g_assert_true (res);
+  g_assert_no_error (error);
+  g_assert (g_strv_length (out_perms) == 0);
+}
+
 static void
 global_setup (void)
 {
@@ -455,11 +563,14 @@ global_setup (void)
   portal_errors = XDG_DESKTOP_PORTAL_ERROR;
 
   g_mkdtemp (outdir);
-  g_print ("outdir: %s\n", outdir);
+  g_debug ("outdir: %s\n", outdir);
 
   g_setenv ("XDG_RUNTIME_DIR", outdir, TRUE);
   g_setenv ("XDG_DATA_HOME", outdir, TRUE);
 
+  /* Re-defining dbus-monitor with a custom script */
+  setup_dbus_daemon_wrapper (outdir);
+
   dbus = g_test_dbus_new (G_TEST_DBUS_NONE);
   services = g_test_build_filename (G_TEST_BUILT, "services", NULL);
   g_test_dbus_add_service_dir (dbus, services);
@@ -552,6 +663,7 @@ main (int argc, char **argv)
 {
   int res;
 
+  g_log_writer_default_set_use_stderr (TRUE);
   g_test_init (&argc, &argv, NULL);
 
   g_test_add_func ("/permissions/version", test_version);
@@ -561,9 +673,13 @@ main (int argc, char **argv)
   g_test_add_func ("/permissions/delete2", test_delete2);
   g_test_add_func ("/permissions/delete3", test_delete3);
   g_test_add_func ("/permissions/delete4", test_delete4);
+  g_test_add_func ("/permissions/delete5", test_delete5);
   g_test_add_func ("/permissions/create1", test_create1);
   g_test_add_func ("/permissions/create2", test_create2);
   g_test_add_func ("/permissions/set-value", test_set_value);
+  g_test_add_func ("/permissions/get-permission1", test_get_permission1);
+  g_test_add_func ("/permissions/get-permission2", test_get_permission2);
+  g_test_add_func ("/permissions/get-permission3", test_get_permission3);
 
   global_setup ();
 
