@@ -4,9 +4,9 @@
 
 #include <gio/gio.h>
 
-#include "src/xdp-dbus.h"
-#include "src/xdp-utils.h"
-#include "src/xdp-impl-dbus.h"
+#include "xdp-dbus.h"
+#include "xdp-utils.h"
+#include "xdp-impl-dbus.h"
 
 #ifdef HAVE_LIBPORTAL
 #include "account.h"
@@ -25,6 +25,16 @@
 #include "wallpaper.h"
 #endif
 
+/* required while we support meson + autotools. Autotools builds everything in
+   the root dir ('.'), meson builds in each subdir nested and overrides these for
+   g_test_build_filename */
+#ifndef XDG_DP_BUILDDIR
+#define XDG_DP_BUILDDIR "."
+#endif
+#ifndef XDG_PS_BUILDDIR
+#define XDG_PS_BUILDDIR "."
+#endif
+
 #define PORTAL_BUS_NAME "org.freedesktop.portal.Desktop"
 #define PORTAL_OBJECT_PATH "/org/freedesktop/portal/desktop"
 #define BACKEND_BUS_NAME "org.freedesktop.impl.portal.Test"
@@ -37,8 +47,8 @@ char outdir[] = "/tmp/xdp-test-XXXXXX";
 static GTestDBus *dbus;
 static GDBusConnection *session_bus;
 static GList *test_procs = NULL;
-XdpImplPermissionStore *permission_store;
-XdpImplLockdown *lockdown;
+XdpDbusImplPermissionStore *permission_store;
+XdpDbusImplLockdown *lockdown;
 
 int
 xdup (int oldfd)
@@ -137,12 +147,12 @@ global_setup (void)
   update_data_dirs ();
 
   g_mkdtemp (outdir);
-  g_print ("outdir: %s\n", outdir);
+  g_debug ("outdir: %s\n", outdir);
 
   g_setenv ("XDG_RUNTIME_DIR", outdir, TRUE);
   g_setenv ("XDG_DATA_HOME", outdir, TRUE);
 
-  /* Re-defining dbus-monitor with a custom script */
+  /* Re-defining dbus-daemon with a custom script */
   setup_dbus_daemon_wrapper (outdir);
 
   dbus = g_test_dbus_new (G_TEST_DBUS_NONE);
@@ -181,7 +191,7 @@ global_setup (void)
   argv[1] = g_test_verbose () ? "--verbose" : NULL;
   argv[2] = NULL;
 
-  g_print ("launching test-backend\n");
+  g_debug ("launching test-backend\n");
 
   subprocess = g_subprocess_launcher_spawnv (launcher, argv, &error);
   g_assert_no_error (error);
@@ -197,6 +207,50 @@ global_setup (void)
   g_source_remove (name_timeout);
   g_bus_unwatch_name (watch);
 
+  /* start permission store */
+  name_appeared = FALSE;
+  watch = g_bus_watch_name_on_connection (session_bus,
+                                          "org.freedesktop.impl.portal.PermissionStore",
+                                          0,
+                                          name_appeared_cb,
+                                          name_disappeared_cb,
+                                          &name_appeared,
+                                          NULL);
+
+  g_clear_object (&launcher);
+  launcher = g_subprocess_launcher_new (G_SUBPROCESS_FLAGS_NONE);
+  g_subprocess_launcher_setenv (launcher, "G_DEBUG", "fatal-criticals", TRUE);
+  g_subprocess_launcher_setenv (launcher, "DBUS_SESSION_BUS_ADDRESS", g_test_dbus_get_bus_address (dbus), TRUE);
+  g_subprocess_launcher_setenv (launcher, "XDG_DATA_HOME", outdir, TRUE);
+  g_subprocess_launcher_setenv (launcher, "PATH", g_getenv ("PATH"), TRUE);
+  g_subprocess_launcher_take_stdout_fd (launcher, xdup (STDERR_FILENO));
+
+  if (g_getenv ("XDP_UNINSTALLED") != NULL)
+    argv0 = g_test_build_filename (G_TEST_BUILT, "..", XDG_PS_BUILDDIR, "xdg-permission-store", NULL);
+  else
+    argv0 = g_strdup (LIBEXECDIR "/xdg-permission-store");
+
+  argv[0] = argv0;
+  argv[1] = "--replace";
+  argv[2] = g_test_verbose () ? "--verbose" : NULL;
+  argv[3] = NULL;
+
+  g_debug ("launching %s\n", argv0);
+
+  subprocess = g_subprocess_launcher_spawnv (launcher, argv, &error);
+  g_assert_no_error (error);
+  g_test_message ("Launched %s with pid %s\n", argv[0],
+                  g_subprocess_get_identifier (subprocess));
+  test_procs = g_list_append (test_procs, g_steal_pointer (&subprocess));
+
+  name_timeout = g_timeout_add (1000 * timeout_mult, timeout_cb, "Failed to launch xdg-permission-store");
+
+  while (!name_appeared)
+    g_main_context_iteration (NULL, TRUE);
+
+  g_source_remove (name_timeout);
+  g_bus_unwatch_name (watch);
+
   /* start portals */
   name_appeared = FALSE;
   watch = g_bus_watch_name_on_connection (session_bus,
@@ -219,7 +273,7 @@ global_setup (void)
   g_subprocess_launcher_take_stdout_fd (launcher, xdup (STDERR_FILENO));
 
   if (g_getenv ("XDP_UNINSTALLED") != NULL)
-    argv0 = g_test_build_filename (G_TEST_BUILT, "..", "xdg-desktop-portal", NULL);
+    argv0 = g_test_build_filename (G_TEST_BUILT, "..", XDG_DP_BUILDDIR, "xdg-desktop-portal", NULL);
   else
     argv0 = g_strdup (LIBEXECDIR "/xdg-desktop-portal");
 
@@ -227,7 +281,7 @@ global_setup (void)
   argv[1] = g_test_verbose () ? "--verbose" : NULL;
   argv[2] = NULL;
 
-  g_print ("launching %s\n", argv0);
+  g_debug ("launching %s\n", argv0);
 
   subprocess = g_subprocess_launcher_spawnv (launcher, argv, &error);
   g_assert_no_error (error);
@@ -244,64 +298,20 @@ global_setup (void)
   g_source_remove (name_timeout);
   g_bus_unwatch_name (watch);
 
-  /* start permission store */
-  name_appeared = FALSE;
-  watch = g_bus_watch_name_on_connection (session_bus,
-                                          "org.freedesktop.impl.portal.PermissionStore",
-                                          0,
-                                          name_appeared_cb,
-                                          name_disappeared_cb,
-                                          &name_appeared,
-                                          NULL);
-
-  g_clear_object (&launcher);
-  launcher = g_subprocess_launcher_new (G_SUBPROCESS_FLAGS_NONE);
-  g_subprocess_launcher_setenv (launcher, "G_DEBUG", "fatal-criticals", TRUE);
-  g_subprocess_launcher_setenv (launcher, "DBUS_SESSION_BUS_ADDRESS", g_test_dbus_get_bus_address (dbus), TRUE);
-  g_subprocess_launcher_setenv (launcher, "XDG_DATA_HOME", outdir, TRUE);
-  g_subprocess_launcher_setenv (launcher, "PATH", g_getenv ("PATH"), TRUE);
-  g_subprocess_launcher_take_stdout_fd (launcher, xdup (STDERR_FILENO));
-
-  if (g_getenv ("XDP_UNINSTALLED") != NULL)
-    argv0 = g_test_build_filename (G_TEST_BUILT, "..", "xdg-permission-store", NULL);
-  else
-    argv0 = g_strdup (LIBEXECDIR "/xdg-permission-store");
-
-  argv[0] = argv0;
-  argv[1] = "--replace";
-  argv[2] = g_test_verbose () ? "--verbose" : NULL;
-  argv[3] = NULL;
-
-  g_print ("launching %s\n", argv0);
-
-  subprocess = g_subprocess_launcher_spawnv (launcher, argv, &error);
-  g_assert_no_error (error);
-  g_test_message ("Launched %s with pid %s\n", argv[0],
-                  g_subprocess_get_identifier (subprocess));
-  test_procs = g_list_append (test_procs, g_steal_pointer (&subprocess));
-
-  name_timeout = g_timeout_add (1000 * timeout_mult, timeout_cb, "Failed to launch xdg-permission-store");
-
-  while (!name_appeared)
-    g_main_context_iteration (NULL, TRUE);
-
-  g_source_remove (name_timeout);
-  g_bus_unwatch_name (watch);
-
-  permission_store = xdp_impl_permission_store_proxy_new_sync (session_bus,
-                                                               0,
-                                                               "org.freedesktop.impl.portal.PermissionStore",
-                                                               "/org/freedesktop/impl/portal/PermissionStore",
-                                                               NULL,
-                                                               &error);
+  permission_store = xdp_dbus_impl_permission_store_proxy_new_sync (session_bus,
+                                                                    0,
+                                                                    "org.freedesktop.impl.portal.PermissionStore",
+                                                                    "/org/freedesktop/impl/portal/PermissionStore",
+                                                                    NULL,
+                                                                    &error);
   g_assert_no_error (error);
 
-  lockdown = xdp_impl_lockdown_proxy_new_sync (session_bus,
-                                               0,
-                                               BACKEND_BUS_NAME,
-                                               BACKEND_OBJECT_PATH,
-                                               NULL,
-                                               &error);
+  lockdown = xdp_dbus_impl_lockdown_proxy_new_sync (session_bus,
+                                                    0,
+                                                    BACKEND_BUS_NAME,
+                                                    BACKEND_OBJECT_PATH,
+                                                    NULL,
+                                                    &error);
   g_assert_no_error (error);
 
   /* make sure errors are registered */
@@ -368,10 +378,6 @@ global_teardown (void)
   g_object_unref (dbus);
 }
 
-/* Just check that the portal is there, and has the
- * expected version. This will fail if the backend
- * is not found.
- */
 #ifdef HAVE_PIPEWIRE
 #define check_pipewire(name)
 #else
@@ -394,6 +400,10 @@ global_teardown (void)
    }
 #endif
 
+/* Just check that the portal is there, and has the
+ * expected version. This will fail if the backend
+ * is not found.
+ */
 #define DEFINE_TEST_EXISTS(pp,PP,version) \
 static void \
 test_##pp##_exists (void) \
@@ -405,18 +415,18 @@ test_##pp##_exists (void) \
  check_pipewire ( #pp ) \
  check_geoclue ( #pp ) \
  \
-  proxy = G_DBUS_PROXY (xdp_##pp##_proxy_new_sync (session_bus, \
-                                                   0, \
-                                                   PORTAL_BUS_NAME, \
-                                                   PORTAL_OBJECT_PATH, \
-                                                   NULL, \
-                                                   &error)); \
+  proxy = G_DBUS_PROXY (xdp_dbus_##pp##_proxy_new_sync (session_bus, \
+                                                        0, \
+                                                        PORTAL_BUS_NAME, \
+                                                        PORTAL_OBJECT_PATH, \
+                                                        NULL, \
+                                                        &error)); \
   g_assert_no_error (error); \
  \
   owner = g_dbus_proxy_get_name_owner (proxy); \
   g_assert_nonnull (owner); \
  \
-  g_assert_cmpuint (xdp_##pp##_get_version (XDP_##PP (proxy)), ==, version); \
+  g_assert_cmpuint (xdp_dbus_##pp##_get_version (XDP_DBUS_##PP (proxy)), ==, version); \
 }
 
 DEFINE_TEST_EXISTS(account, ACCOUNT, 1)
@@ -443,6 +453,8 @@ main (int argc, char **argv)
 {
   int res;
 
+  g_log_writer_default_set_use_stderr (TRUE);
+
   setlocale (LC_ALL, NULL);
 
   g_test_init (&argc, &argv, NULL);
